@@ -2,9 +2,10 @@
 from .viewer import run 
 from .viewer_kernel import ViewerKernel
 from .xpcs_file import XpcsFile as xf
+from .xpcs_file import XpcsFile
 
 
-__all__ = [run, xf]
+__all__ = [run, xf, XpcsFile]
 __version__ = '0.1.0'
 __author__ = 'Miaoqi Chu'
 __credits__ = 'Argonne National Laboratory'
