@@ -111,7 +111,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.show_g2_fit_summary.clicked.connect(self.show_g2_fit_summary_func)
         self.hdf_key_filter.textChanged.connect(self.show_hdf_info)
         self.btn_g2_refit.clicked.connect(self.plot_g2)
+        self.saxs2d_autorange.stateChanged.connect(self.update_saxs2d_range)
         self.load_default_setting()
+        self.btn_deselect.clicked.connect(self.clear_target_selection)
+        self.list_view_target.doubleClicked.connect(self.edit_label)
 
         # self.btn_g2_export.clicked.connect(self.export_g2)
         # disable browse function; it freezes on linux workstation;
@@ -239,6 +242,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.statusbar.showMessage('Files loaded.', 1000)
 
         self.init_tab()
+        self.btn_load_data.setDisabled(True)
+        self.btn_load_data.setText('updated')
+        self.btn_load_data.repaint()
+
 
     def update_hdf_list(self):
         self.hdf_list.clear()
@@ -265,6 +272,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'cmap': self.cb_saxs2D_cmap.currentText(),
             'autorotate': self.saxs2d_autorotate.isChecked(),
             'display': self.saxs2d_display,
+            'autorange': self.saxs2d_autorange.isChecked(),
+            'vmin': self.saxs2d_min.value(),
+            'vmax': self.saxs2d_max.value(),
         }
         self.vk.plot_saxs_2d(pg_hdl=self.pg_saxs, **kwargs)
 
@@ -278,7 +288,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'plot_norm': self.cb_saxs_norm.currentIndex(),
             'rows': self.get_selected_rows(),
             'qmin': self.saxs1d_qmin.value(),
-            'qmax': self.saxs1d_qmax.value()
+            'qmax': self.saxs1d_qmax.value(),
+            'loc': self.saxs1d_legend_loc.currentText(),
+            'marker_size': self.sb_saxs_marker_size.value(),
+            'sampling': self.saxs1d_sampling.value()
         }
         if kwargs['qmin'] >= kwargs['qmax']:
             self.statusbar.showMessage('check qmin and qmax')
@@ -650,10 +663,13 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'q_range': (p[0], p[1]),
             't_range': (p[2], p[3]),
             'y_range': (p[4], p[5]),
+            'y_auto': self.g2_yauto.isChecked(),
             'rows': self.get_selected_rows(),
             'bounds': bounds,
             'fit_flag': fit_flag,
-            'subtract_baseline': self.g2_sub_baseline.isChecked()
+            'marker_size': self.g2_marker_size.value(),
+            'subtract_baseline': self.g2_sub_baseline.isChecked(),
+            # 'label_size': self.sb_g2_label_size.value(),
         }
         if kwargs['show_fit'] and sum(kwargs['fit_flag']) == 0:
             self.statusbar.showMessage('nothing to fit, really?', 1000)
@@ -662,7 +678,10 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.pushButton_4.setDisabled(True)
         self.pushButton_4.setText('plotting')
 
-        self.vk.plot_g2(handler=self.mp_g2, **kwargs)
+        try:
+            self.vk.plot_g2(handler=self.mp_g2, **kwargs)
+        except ZeroDivisionError:
+            self.statusbar.showMessage('check range', 1000)
 
         self.pushButton_4.setEnabled(True)
         self.pushButton_4.setText('plot')
@@ -682,6 +701,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
     def reload_source(self):
         self.vk.build()
         self.update_box(self.vk.source, mode='source')
+        self.trie_search()
 
     def load_path(self, path=None, debug=False):
         if path in [None, False]:
@@ -760,6 +780,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             return
 
         # the target list has changed;
+        self.btn_load_data.setText('update')
+        self.btn_load_data.setEnabled(True)
+        self.btn_load_data.repaint()
         self.update_box(self.vk.target, mode='target')
 
         if self.data_state in [1, 2, 3]:
@@ -774,6 +797,11 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         if self.tab_dict[tab_id] == 'average':
             self.update_average_box()
         elif self.box_auto_update.isChecked():
+            if self.tab_dict[tab_id] in ['saxs_1d', 'g2']:
+                self.statusbar.showMessage(
+                    'Auto loading is disabled for saxs_1d and g2', 1000)
+                self.statusbar.repaint()
+                return
             # avoid pressing enter when auto-load is enabled and lots of
             # files are added; it'll take long time to process;
             if len(self.vk.target) > 128:
@@ -924,6 +952,26 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.statusbar.showMessage(msg, 1000)
 
         return flag
+    
+    def update_saxs2d_range(self, flag=True):
+        if not flag:
+            vmin = self.pg_saxs.levelMin
+            vmax = self.pg_saxs.levelMax
+            if vmin is not None:
+                self.saxs2d_min.setValue(vmin)
+            if vmax is not None:
+                self.saxs2d_max.setValue(vmax)
+            self.saxs2d_min.setEnabled(True)
+            self.saxs2d_max.setEnabled(True)
+        else:
+            self.saxs2d_min.setDisabled(True)
+            self.saxs2d_max.setDisabled(True)
+        
+        self.saxs2d_min.parent().repaint()
+    
+    def clear_target_selection(self):
+        self.list_view_target.clearSelection()
+        self.list_view_source.repaint()
 
 
 def setup_windows_icon():
